@@ -1,6 +1,6 @@
 #include "aboutdlg.h"
 #include "ui_aboutdlg.h"
-#include "creditsdlg.h"
+
 
 AboutDlg::AboutDlg(QWidget *parent) :
     QDialog(parent),
@@ -16,13 +16,13 @@ AboutDlg::~AboutDlg()
 
 void AboutDlg::on_creditsButton_clicked()
 {
-    CreditsDlg *credits = new CreditsDlg(this);
+    credits = new CreditsDlg(this);
     credits->exec();
 }
 
 void AboutDlg::on_licenseButton_clicked()
 {
-    LicenseDlg *license = new LicenseDlg(this);
+    license = new LicenseDlg(this);
     license->exec();
 }
 
