@@ -2,6 +2,7 @@
 #define ABOUTDLG_H
 
 #include "licensedlg.h"
+#include "creditsdlg.h"
 #include <QtGui/QDialog>
 #include <QDesktopServices>
 #include <QUrl>
@@ -21,6 +22,8 @@ public:
 
 private:
     Ui::AboutDlg *m_ui;
+    CreditsDlg *credits;
+    LicenseDlg *license;
 
 private slots:
     //! Opens credits dialog.
