@@ -12,7 +12,7 @@ class BackgroundColorDlg : public QDialog {
     Q_DISABLE_COPY(BackgroundColorDlg)
 public:
     //! Constructor.
-    explicit BackgroundColorDlg(QWidget *parent = 0, QColor color = 0);
+    explicit BackgroundColorDlg(QWidget *parent = 0, QColor color = Qt::black);
     //! Destructor.
     virtual ~BackgroundColorDlg();
 	
