@@ -88,8 +88,6 @@ void BackgroundDlg::on_defaultImageButton_clicked()
 
 void BackgroundDlg::on_colorButton_clicked()
 {
-    QPalette palette;
-
     bool ok;
     QColor color(redString.toInt(&ok,10),greenString.toInt(&ok,10),blueString.toInt(&ok,10));
 
@@ -131,6 +129,18 @@ void BackgroundDlg::on_imageButton_clicked()
 
               m_ui->background->setPixmap(pix);
               backgroundPixmap = pix.scaled(800,424,Qt::IgnoreAspectRatio,Qt::FastTransformation);
+
+              QColor defaultBgColor(50,50,50);
+              palette.setColor(QPalette::Window,defaultBgColor);
+              m_ui->background->setPalette(palette);
+              m_ui->background->setAutoFillBackground(true);
+
+              pm = QPixmap(120,80);
+              pm.fill(QColor(50,50,50));
+
+              QIcon colorDlgButtonIcon = QIcon(pm);
+              m_ui->colorButton->setIconSize(QSize(25,25));
+              m_ui->colorButton->setIcon(colorDlgButtonIcon);
          }
     }
     backgroundImagePath = bgImagePath;
@@ -198,7 +208,6 @@ void BackgroundDlg::activateTab(const int tabIndex)
 
             backgroundColor = QColor(redString.toInt(&ok,10),greenString.toInt(&ok,10),blueString.toInt(&ok,10));
 
-            QPalette palette;
             bgMode = backgroundFromColor;
             defaultImageSelected = false;
             m_ui->background->clear();
