@@ -7,6 +7,7 @@
 LayoutWidget::LayoutWidget(QMainWindow *parent ) : QWidget( parent )
 {
     this->resize(800,424);
+    this->setMinimumHeight(424);
     setAcceptDrops(true);
     useModeEnabled = true;
     snapToGridEnabled = false;
@@ -18,7 +19,7 @@ LayoutWidget::LayoutWidget(QMainWindow *parent ) : QWidget( parent )
     timer2Index = 0;
     timeout2 = 1;
     connect(timer,SIGNAL(timeout()),this,SLOT(sendIrCommandsSlot()));
-    connect(timer2,SIGNAL(timeout()),this,SLOT(sendIrCommandsSlot2()));
+    connect(timer2,SIGNAL(timeout()),this,SLOT(sendMultipleIrCommandsSlot()));
     timer->setInterval(100);
     timer2->setInterval(timeout2);
 }
@@ -38,7 +39,7 @@ void LayoutWidget::setUseModeEnabled(bool useMode)
 
 void LayoutWidget::openEditDlg()
 {
-    NewButtonDlg *newButtonDlg = new NewButtonDlg(this,vector->at(currentButtonIndex), vector);
+    newButtonDlg = new NewButtonDlg(this,vector->at(currentButtonIndex), vector);
     connect(newButtonDlg,SIGNAL(addButtonToLayoutSignal(QString,QString, QString, QString,QStringList,int,int)),
             this,SLOT(editButton(QString,QString, QString, QString, QStringList,int,int)));
 
@@ -53,9 +54,7 @@ void LayoutWidget::editButton(QString fileNameUnPressed, QString fileNamePressed
 
      ButtonWidget *pw = new ButtonWidget(this, fileNameUnPressed, fileNamePressed, confFileName, buttonText, commands, timeOut);
 
-     int buttonWidgets;
-     buttonWidgets = vector->count();
-     for(int i=0;i<buttonWidgets;i++) {
+     for(int i=0;i<vector->count();i++) {
         if(vector->at(i)->buttonText == newButton->buttonText) {
             vector->replace(i,pw);
         }
@@ -75,6 +74,7 @@ void LayoutWidget::mousePressEvent(QMouseEvent *event)
 {
     ButtonWidget *child = static_cast<ButtonWidget*>(childAt(event->pos()));
     if(child) {
+
         QPoint hotSpot = event->pos() - child->pos();
         xPos = child->x();
         yPos = child->y();
@@ -199,9 +199,7 @@ void LayoutWidget::dragEnterEvent(QDragEnterEvent *event)
              }
              newButton->setAttribute(Qt::WA_DeleteOnClose);
 
-             int buttonWidgets;
-             buttonWidgets = vector->count();
-             for(int i=0;i<buttonWidgets;i++) {
+             for(int i=0;i<vector->count();i++) {
                 if(vector->at(i)->buttonText == newButton->buttonText) {
                     vector->replace(i,newButton);
                     currentButtonIndex = i;
@@ -217,17 +215,14 @@ void LayoutWidget::dragEnterEvent(QDragEnterEvent *event)
          else event->ignore();
 
          // Move button to limit area if it goes over screen area
-         int buttonWidth = newButton->width();
-         int buttonHeight = newButton->height();
-
-         if(((newButton->x())+(buttonWidth)) > 800)
-            newButton->move(800-buttonWidth,newButton->y());
+         if(((newButton->x())+(newButton->width())) > 800)
+            newButton->move(800-newButton->width(),newButton->y());
 
          if(newButton->x() < 0) {
             newButton->move(0,newButton->y());
          }
-         if(newButton->y()+buttonHeight > 424)
-            newButton->move(newButton->x(),424 - buttonHeight);
+         if(newButton->y()+newButton->height() > 424)
+            newButton->move(newButton->x(),424 - newButton->height());
 
          if(newButton->y() <= 0) {
             newButton->move(newButton->x(),0);
@@ -249,15 +244,29 @@ void LayoutWidget::dragEnterEvent(QDragEnterEvent *event)
              QAction *deleteButton = menu->addAction("Delete button");
 
              connect(editButton,SIGNAL(triggered()),this,SLOT(openEditDlg()));
-             connect(deleteButton,SIGNAL(triggered()),this,SLOT(deleteButton()));
+             connect(deleteButton,SIGNAL(triggered()),this,SLOT(confirmDelete()));
              menu->show();
          }
      }
     else timer->stop();
 }
 
+void LayoutWidget::confirmDelete()
+{
+    deleteButtonDlg = new QDialog(this);
+    deleteButtonDlg->setWindowTitle("Really delete button?");
+    deleteButtonDlg->resize(800,120);
+    QPushButton *del = new QPushButton(deleteButtonDlg);
+    del->setGeometry(300,20,200,70);
+    del->setText("Delete");
+    connect(del,SIGNAL(clicked()),this,SLOT(deleteButton()));
+    del->show();
+    deleteButtonDlg->exec();
+}
+
 void LayoutWidget::deleteButton()
 {
+    deleteButtonDlg->close();
     vector->at(currentButtonIndex)->deleteLater();
     vector->remove(currentButtonIndex);
 }
@@ -462,8 +471,7 @@ void LayoutWidget::sendIrCommands(QStringList commands)
         if(!connected)  QMessageBox::warning(this,"Socket connection","Socket connection with lirc failed! Please try reopening software.");
         const QString command = "SEND_ONCE " +commands.at(0);
         socket->sendSocket(&command);
-        bool disconnect = socket->disconnectSocket();
-        if(disconnect != 0) QMessageBox::warning(this,"Socket connection","Socket disconnection with lirc failed! Please try reopening software.");
+        socket->disconnectSocket();
 
     }
     else {
@@ -477,7 +485,7 @@ void LayoutWidget::sendIrCommandsSlot()
     sendIrCommands(copyButton->commandChain);
 
 }
-void LayoutWidget::sendIrCommandsSlot2()
+void LayoutWidget::sendMultipleIrCommandsSlot()
 {
 
     if(timer2Index < copyButton->commandChain.count()) {
@@ -486,8 +494,8 @@ void LayoutWidget::sendIrCommandsSlot2()
          if(!connected)  QMessageBox::warning(this,"Socket connection","Socket connection with lirc failed! Please try reopening software.");
          const QString command = "SEND_ONCE " +copyButton->commandChain.at(timer2Index);
          socket->sendSocket(&command);
-         bool disconnect = socket->disconnectSocket();
-         if(disconnect != 0) QMessageBox::warning(this,"Socket connection","Socket disconnection with lirc failed! Please try reopening software.");
+         socket->disconnectSocket();
+
          timer2Index++;
          timeout2 = copyButton->timeOut;
          timer2->setInterval(timeout2);
