@@ -16,6 +16,7 @@
 class QDragEnterEvent;
 class QDropEvent;
 class ButtonWidget;
+class NewButtonDlg;
 
 class LayoutWidget: public QWidget
 {
@@ -44,8 +45,9 @@ public:
     //! Boolean to tell if snap to grid enabled.
     bool snapToGridEnabled;
 
-
 private:
+    NewButtonDlg *newButtonDlg;
+    QDialog *deleteButtonDlg;
     //! Boolean to tell if using mode enabled or disabled.
     bool useModeEnabled;
     //! Background RGB values.
@@ -105,9 +107,11 @@ private slots:
     void sendIrCommands(QStringList commands);
     //! Slot called when delete button in button menu clicked.
     void deleteButton();
+    //! Dialog to ask if user really wants to delete button.
+    void confirmDelete();
     //! Timer slot.
     void sendIrCommandsSlot();
     //! Timer2 slot.
-    void sendIrCommandsSlot2();
+    void sendMultipleIrCommandsSlot();
 };
 #endif // LAYOUTWIDGET_H
