@@ -16,9 +16,6 @@ public:
     //! Destructor.
     virtual ~LicenseDlg();
 
-protected:
-    virtual void changeEvent(QEvent *e);
-
 private:
     Ui::LicenseDlg *m_ui;
 };
