@@ -3,6 +3,7 @@
 
 #include <QtGui/QDialog>
 #include "qxtxmlrpcclient.h"
+#include "registerdlg.h"
 
 namespace Ui {
     class LoginDbDlg;
@@ -17,11 +18,9 @@ public:
     //! Destructor.
     virtual ~LoginDbDlg();
 
-protected:
-    virtual void changeEvent(QEvent *e);
-
 private:
     Ui::LoginDbDlg *m_ui;
+    RegisterDlg *regDlg;
     //! Used for PHP calls.
     QxtXmlRpcClient *client;
     //! Id used with client.
