@@ -21,10 +21,10 @@ QtIrreco::QtIrreco(QWidget *parent)
     file.close();
 
     remoteNames = new QStringList();
-    lw = new LayoutWidget(this);
 
+
+    lw = new LayoutWidget(this);
     lw->show();
-    lw->setFocus();
 
     connect(this,SIGNAL(remoteNameToLw(QString)),lw,SLOT(setActiveRemoteName(QString)));
     connect(this,SIGNAL(bgImageToLw(QString)),lw,SLOT(setBackgroundImagePath(QString)));
@@ -60,6 +60,7 @@ QtIrreco::~QtIrreco()
     delete m_ui;
 
 }
+
 void QtIrreco::createFoldersAndFiles()
 {
     QDir qtirreco;
@@ -161,9 +162,10 @@ void QtIrreco::createRemote(QString newRemoteName)
     QString newRemoteFileName = (newRemoteName+".conf");
     for(int i=0;i<remoteNames->count();i++) {
         if(remoteNames->at(i) == newRemoteFileName) {
-            QMessageBox::warning(this,"Remote name already exists!","Please choose a different remote name.",
+            QMessageBox::warning(this,"Remote "+ newRemoteName+ " already exists!","Please choose a different remote name.",
                                  QMessageBox::NoButton,QMessageBox::NoButton);
             alreadyExists = true;
+            this->newRemote();
         }
     }
     if(!alreadyExists) {
@@ -229,28 +231,27 @@ void QtIrreco::changeNewRemoteName(QString newName)
 {
     bool alreadyExists = false;
     for(int i=0;i<remoteNames->count();i++) {
-        if(remoteNames->at(i).contains(newName))
+        if(remoteNames->at(i) == (newName+".conf"))
             alreadyExists = true;
-
     }
     if(alreadyExists) {
-            QMessageBox::warning(this,"Remote name already exists!","Please choose different remote name.",
-                         QMessageBox::NoButton,QMessageBox::NoButton);
-            rrDlg2 = new RenameRemoteDlg(this,activeRemote);
-            connect(rrDlg2,SIGNAL(changeName(QString)),this,SLOT(changeNewRemoteName(QString)));
-            rrDlg2->setLabelGeometry(230,10,360,31);
-            rrDlg2->exec();
+            QMessageBox::warning(this,"Remote "+ newName+ " already exists!","Please choose a different remote name.",
+                     QMessageBox::NoButton,QMessageBox::NoButton);
+            this->renameRemote();
 
     }
     else {
         oldRemoteName = activeRemote;
         QFile remoteFile(remotesPath + oldRemoteName + ".conf");
         remoteFile.rename(newName+".conf");
+        remoteFile.close();
+        QFile oldRemoteFile(remotesPath + oldRemoteName + ".conf");
+        oldRemoteFile.remove();
         activeRemote = newName;
         this->setWindowTitle("QtIrreco:"+activeRemote);
         lw->setActiveRemoteName(activeRemote);
         for(int i=0;i<remoteNames->count();i++) {
-            if(remoteNames->at(i).contains(oldRemoteName))
+            if(remoteNames->at(i) == (oldRemoteName+".conf"))
                 remoteNames->replace(i,activeRemote+".conf");
 
         }
@@ -419,6 +420,7 @@ void QtIrreco::saveRemote()
     useModeEnabled = true;
     lw->setUseModeEnabled(useModeEnabled);
     lw->setFocus();
+
     lw->saveRemoteToFile();
     lircFileNames.clear();
 
@@ -644,13 +646,16 @@ void QtIrreco::background()
 {
     bg = new BackgroundDlg(this,activeRemote);
     connect(bg,SIGNAL(backgroundChanged(int)),lw,SLOT(setBackgroundMode(int)));
-    connect(bg,SIGNAL(backgroundChanged(int)),this,SLOT(changeBackground()));
+    connect(bg,SIGNAL(backgroundChanged(int)),this,SLOT(changeBackground(int)));
     connect(bg,SIGNAL(rgbToLw(QString,QString,QString)),lw,SLOT(setRgbValues(QString,QString,QString)));
+    connect(bg,SIGNAL(rgbToLw(QString,QString,QString)),this,SLOT(setRgbValues(QString,QString,QString)));
     bg->exec();
 }
 
-void QtIrreco::changeBackground()
+void QtIrreco::changeBackground(int bgMode)
 {
+    backgroundMode = backgroundModes(bgMode);
+    backgroundName = bg->returnBackgroundImagePath();
     lw->setBackgroundImagePath(bg->returnBackgroundImagePath());
 
     if(bg->isDefaultImageSelected()) {
@@ -668,13 +673,18 @@ void QtIrreco::changeBackground()
         QPixmap backImage = bg->returnBackgroundPixmap();
         QPixmap backColor = bg->returnBackgroundPixmapColor();
 
-        if(!backColor.isNull()) {
+        if(!backColor.isNull() && backgroundMode == backgroundFromColor) {
             palette.setBrush(QPalette::Window,backColor);
             this->setPalette(palette);
             this->setAutoFillBackground(true);
         }
 
         if(!backImage.isNull()) {
+            QColor defaultBgColor(50,50,50);
+            palette.setColor(QPalette::Window,defaultBgColor);
+            this->setPalette(palette);
+            this->setAutoFillBackground(true);
+
             palette.setBrush(QPalette::Window, backImage);
             lw->setPalette(palette);
             lw->setAutoFillBackground(true);
@@ -714,6 +724,15 @@ void QtIrreco::changeBackground(QString backgroundName, QColor backgroundColor)
         }
     }
 }
+
+void QtIrreco::setRgbValues(QString red, QString green, QString blue)
+{
+    bool ok;
+    r = red.toInt(&ok,10);
+    g = green.toInt(&ok,10);
+    b = blue.toInt(&ok,10);
+}
+
 void QtIrreco::initMenu()
 {
     m_ui->menu->setTitle("");
@@ -811,7 +830,8 @@ void QtIrreco::addDownloadedRemote(QString remName)
     lastTheme = false;
     QString remConf = remName;
     remConf.chop(5);
-    remoteNames->append(remName);
+    if(!remoteNames->contains((remName),Qt::CaseInsensitive))
+        remoteNames->append(remName);
     activeRemote = remConf;
     //Downloads Lirc configurations if needed
     checkLircFilesForRemote(remName);
@@ -841,7 +861,6 @@ void QtIrreco::checkThemesForRemote(QString remoteFile)
                     else {
                         themesForRemote.append(themeTemp);
                         themeTemp.clear();
-
                     }
                 }
 
