@@ -180,7 +180,8 @@ private slots:
     void newButton();
     void saveRemote();
     void background();
-    void changeBackground();
+    void changeBackground(int bgMode);
+    void setRgbValues(QString red, QString green, QString blue);
     void selectRemote();
     void changeNewRemoteName(QString newName);
     void createRemote(QString newRemoteName);
