@@ -16,17 +16,7 @@ RenameRemoteDlg::~RenameRemoteDlg()
 {
     delete m_ui;
 }
-void RenameRemoteDlg::changeEvent(QEvent *e)
-{
-    QDialog::changeEvent(e);
-    switch (e->type()) {
-    case QEvent::LanguageChange:
-        m_ui->retranslateUi(this);
-        break;
-    default:
-        break;
-    }
-}
+
 void RenameRemoteDlg::on_changeNameButton_clicked()
 {
     if(!m_ui->remoteNameLine->text().isEmpty()) {
