@@ -1,31 +1,27 @@
 #include "themepreviewbuttondlg.h"
 #include "ui_themepreviewbuttondlg.h"
+#include "definitions.h"
 
 ThemePreviewButtonDlg::ThemePreviewButtonDlg(QWidget *parent,QVector <ThemeCreatorButton*> *buttonsVector) :
     QDialog(parent),
     m_ui(new Ui::ThemePreviewButtonDlg)
 {
     m_ui->setupUi(this);
+    m_ui->previewScrollArea->setProperty("FingerScrollable",true);
     buttons = new QVector <QLabel*>();
     paths = new QVector <QString>();
     names = new QVector <QString>();
     int count=0;
     int row=0;
     int x=0;
-    for(int i=0;i<buttonsVector->count();i++)
-    {
+    for(int i=0;i<buttonsVector->count();i++) {
         if(count == 0)
-        {
-            x = 20+20+count*128;
-        }
+            x = 40+count*128;
+
         else if(count == 1)
-        {
-            x = 20+20+count*128;
-        }
-        else
-        {
-            x = 20+20*count+count*128;
-        }
+            x = 60+count*128;
+
+        else x = (40*count+count*128) - (20*(count-2));
 
         QLabel *button = new QLabel(m_ui->previewScrollAreaWidgetContents);
         button->setGeometry(x,20+row*148,128,128);
@@ -35,16 +31,11 @@ ThemePreviewButtonDlg::ThemePreviewButtonDlg(QWidget *parent,QVector <ThemeCreat
         buttons->append(button);
         paths->append(buttonsVector->at(i)->unpressedPath);
         names->append(buttonsVector->at(i)->buttonName);
-        if(x > 500)
-        {
+        if(x > 484) {
             x = 0;
-           // x = 40+count*128;
             count = -1;
             row++;
-            //if(row>1)
-            //{
-                m_ui->previewScrollAreaWidgetContents->setMinimumHeight(250*row);
-            //}
+            m_ui->previewScrollAreaWidgetContents->setMinimumHeight(256+128*row);
         }
         count++;
     }
