@@ -62,13 +62,13 @@ void UploadDBDlg::uploadRemote(QString username,QString pwd)
     while (!in.atEnd()) {
 
         line = in.readLine();
-        if(line.contains("Background:"))
+        if(line.contains(("Background:"),Qt::CaseInsensitive))
             uploadable = true;
-        if(prevLine.contains("Background: default")) {
+        if(prevLine.contains(("Background: default"),Qt::CaseInsensitive)) {
             line = "Image: default";
             prevLine.clear();
         }
-        if(line.contains("Background: image")) {
+        if(line.contains(("Background: image"),Qt::CaseInsensitive)) {
                     QMessageBox::information(this,"Remote upload","Remote will be uploaded with default background.",
                              QMessageBox::NoButton,QMessageBox::NoButton);
                     line = "Background: default";
