@@ -4,6 +4,7 @@
 #include <QtGui/QDialog>
 #include <QMessageBox>
 #include "qxtxmlrpcclient.h"
+#include "logindbdlg.h"
 #include "definitions.h"
 
 namespace Ui {
@@ -19,11 +20,9 @@ public:
     //! Destructor.
     virtual ~UploadDBDlg();
 
-protected:
-    virtual void changeEvent(QEvent *e);
-
 private:
     Ui::UploadDBDlg *m_ui;
+    LoginDbDlg *loginDlg;
     QxtXmlRpcClient *client;
     //! Used for client calls.
     int categoryId;
